==> simul-fish-growth-portlet-1.0-20160323.134726-1-sources.jar: gr/i2s/bluebridge/simul/model/Site.java <==
package gr.i2s.bluebridge.simul.model;

public class Site extends EntityWithId {
	int periodJanA;
	int periodJanB;
	int periodFebA;
	int periodFebB;
	int periodMarA;
	int periodMarB;
	int periodAprA;
	int periodAprB;
	int periodMayA;
	int periodMayB;
	int periodJunA;
	int periodJunB;
	int periodJulA;
	int periodJulB;
	int periodAugA;
	int periodAugB;
	int periodSepA;
	int periodSepB;
	int periodOctA;
	int periodOctB;
	int periodNovA;
	int periodNovB;
	int periodDecA;
	int periodDecB;
	long oxygenRatingId;
	long currentRatingId;
	long regionId;
	
	public int getPeriodJanA() {
		return periodJanA;
	}

	public void setPeriodJanA(int periodJanA) {
		this.periodJanA = periodJanA;
	}

	public int getPeriodJanB() {
		return periodJanB;
	}

	public void setPeriodJanB(int periodJanB) {
		this.periodJanB = periodJanB;
	}

	public int getPeriodFebA() {
		return periodFebA;
	}

	public void setPeriodFebA(int periodFebA) {
		this.periodFebA = periodFebA;
	}

	public int getPeriodFebB() {
		return periodFebB;
	}

	public void setPeriodFebB(int periodFebB) {
		this.periodFebB = periodFebB;
	}

	public int getPeriodMarA() {
		return periodMarA;
	}

	public void setPeriodMarA(int periodMarA) {
		this.periodMarA = periodMarA;
	}

	public int getPeriodMarB() {
		return periodMarB;
	}

	public void setPeriodMarB(int periodMarB) {
		this.periodMarB = periodMarB;
	}

	public int getPeriodAprA() {
		return periodAprA;
	}

	public void setPeriodAprA(int periodAprA) {
		this.periodAprA = periodAprA;
	}

	public int getPeriodAprB() {
		return periodAprB;
	}

	public void setPeriodAprB(int periodAprB) {
		this.periodAprB = periodAprB;
	}

	public int getPeriodMayA() {
		return periodMayA;
	}

	public void setPeriodMayA(int periodMayA) {
		this.periodMayA = periodMayA;
	}

	public int getPeriodMayB() {
		return periodMayB;
	}

	public void setPeriodMayB(int periodMayB) {
		this.periodMayB = periodMayB;
	}

	public int getPeriodJunA() {
		return periodJunA;
	}

	public void setPeriodJunA(int periodJunA) {
		this.periodJunA = periodJunA;
	}

	public int getPeriodJunB() {
		return periodJunB;
	}

	public void setPeriodJunB(int periodJunB) {
		this.periodJunB = periodJunB;
	}

	public int getPeriodJulA() {
		return periodJulA;
	}

	public void setPeriodJulA(int periodJulA) {
		this.periodJulA = periodJulA;
	}

	public int getPeriodJulB() {
		return periodJulB;
	}

	public void setPeriodJulB(int periodJulB) {
		this.periodJulB = periodJulB;
	}

	public int getPeriodAugA() {
		return periodAugA;
	}

	public void setPeriodAugA(int periodAugA) {
		this.periodAugA = periodAugA;
	}

	public int getPeriodAugB() {
		return periodAugB;
	}

	public void setPeriodAugB(int periodAugB) {
		this.periodAugB = periodAugB;
	}

	public int getPeriodSepA() {
		return periodSepA;
	}

	public void setPeriodSepA(int periodSepA) {
		this.periodSepA = periodSepA;
	}

	public int getPeriodSepB() {
		return periodSepB;
	}

	public void setPeriodSepB(int periodSepB) {
		this.periodSepB = periodSepB;
	}

	public int getPeriodOctA() {
		return periodOctA;
	}

	public void setPeriodOctA(int periodOctA) {
		this.periodOctA = periodOctA;
	}

	public int getPeriodOctB() {
		return periodOctB;
	}

	public void setPeriodOctB(int periodOctB) {
		this.periodOctB = periodOctB;
	}

	public int getPeriodNovA() {
		return periodNovA;
	}

	public void setPeriodNovA(int periodNovA) {
		this.periodNovA = periodNovA;
	}

	public int getPeriodNovB() {
		return periodNovB;
	}

	public void setPeriodNovB(int periodNovB) {
		this.periodNovB = periodNovB;
	}

	public int getPeriodDecA() {
		return periodDecA;
	}

	public void setPeriodDecA(int periodDecA) {
		this.periodDecA = periodDecA;
	}

	public int getPeriodDecB() {
		return periodDecB;
	}

	public void setPeriodDecB(int periodDecB) {
		this.periodDecB = periodDecB;
	}

	public long getOxygenRatingId() {
		return oxygenRatingId;
	}

	public void setOxygenRatingId(long oxygenRatingId) {
		this.oxygenRatingId = oxygenRatingId;
	}

	public long getCurrentRatingId() {
		return currentRatingId;
	}

	public void setCurrentRatingId(long currentRatingId) {
		this.currentRatingId = currentRatingId;
	}

	public long getRegionId() {
		return regionId;
	}

	public void setRegionId(long regionId) {
		this.regionId = regionId;
	}

}

==> simul-fish-growth-portlet-1.0-20160404.170301-3-sources.jar: gr/i2s/bluebridge/simul/model/Site.java <==
package gr.i2s.bluebridge.simul.model;

public class Site extends EntityWithUserId {
	int periodJanA;
	int periodJanB;
	int periodFebA;
	int periodFebB;
	int periodMarA;
	int periodMarB;
	int periodAprA;
	int periodAprB;
	int periodMayA;
	int periodMayB;
	int periodJunA;
	int periodJunB;
	int periodJulA;
	int periodJulB;
	int periodAugA;
	int periodAugB;
	int periodSepA;
	int periodSepB;
	int periodOctA;
	int periodOctB;
	int periodNovA;
	int periodNovB;
	int periodDecA;
	int periodDecB;
	long oxygenRatingId;
	long currentRatingId;
	long regionId;

	public int getPeriodJanA() {
		return periodJanA;
	}

	public void setPeriodJanA(int periodJanA) {
		this.periodJanA = periodJanA;
	}

	public int getPeriodJanB() {
		return periodJanB;
	}

	public void setPeriodJanB(int periodJanB) {
		this.periodJanB = periodJanB;
	}

	public int getPeriodFebA() {
		return periodFebA;
	}

	public void setPeriodFebA(int periodFebA) {
		this.periodFebA = periodFebA;
	}

	public int getPeriodFebB() {
		return periodFebB;
	}

	public void setPeriodFebB(int periodFebB) {
		this.periodFebB = periodFebB;
	}

	public int getPeriodMarA() {
		return periodMarA;
	}

	public void setPeriodMarA(int periodMarA) {
		this.periodMarA = periodMarA;
	}

	public int getPeriodMarB() {
		return periodMarB;
	}

	public void setPeriodMarB(int periodMarB) {
		this.periodMarB = periodMarB;
	}

	public int getPeriodAprA() {
		return periodAprA;
	}

	public void setPeriodAprA(int periodAprA) {
		this.periodAprA = periodAprA;
	}

	public int getPeriodAprB() {
		return periodAprB;
	}

	public void setPeriodAprB(int periodAprB) {
		this.periodAprB = periodAprB;
	}

	public int getPeriodMayA() {
		return periodMayA;
	}

	public void setPeriodMayA(int periodMayA) {
		this.periodMayA = periodMayA;
	}

	public int getPeriodMayB() {
		return periodMayB;
	}

	public void setPeriodMayB(int periodMayB) {
		this.periodMayB = periodMayB;
	}

	public int getPeriodJunA() {
		return periodJunA;
	}

	public void setPeriodJunA(int periodJunA) {
		this.periodJunA = periodJunA;
	}

	public int getPeriodJunB() {
		return periodJunB;
	}

	public void setPeriodJunB(int periodJunB) {
		this.periodJunB = periodJunB;
	}

	public int getPeriodJulA() {
		return periodJulA;
	}

	public void setPeriodJulA(int periodJulA) {
		this.periodJulA = periodJulA;
	}

	public int getPeriodJulB() {
		return periodJulB;
	}

	public void setPeriodJulB(int periodJulB) {
		this.periodJulB = periodJulB;
	}

	public int getPeriodAugA() {
		return periodAugA;
	}

	public void setPeriodAugA(int periodAugA) {
		this.periodAugA = periodAugA;
	}

	public int getPeriodAugB() {
		return periodAugB;
	}

	public void setPeriodAugB(int periodAugB) {
		this.periodAugB = periodAugB;
	}

	public int getPeriodSepA() {
		return periodSepA;
	}

	public void setPeriodSepA(int periodSepA) {
		this.periodSepA = periodSepA;
	}

	public int getPeriodSepB() {
		return periodSepB;
	}

	public void setPeriodSepB(int periodSepB) {
		this.periodSepB = periodSepB;
	}

	public int getPeriodOctA() {
		return periodOctA;
	}

	public void setPeriodOctA(int periodOctA) {
		this.periodOctA = periodOctA;
	}

	public int getPeriodOctB() {
		return periodOctB;
	}

	public void setPeriodOctB(int periodOctB) {
		this.periodOctB = periodOctB;
	}

	public int getPeriodNovA() {
		return periodNovA;
	}

	public void setPeriodNovA(int periodNovA) {
		this.periodNovA = periodNovA;
	}

	public int getPeriodNovB() {
		return periodNovB;
	}

	public void setPeriodNovB(int periodNovB) {
		this.periodNovB = periodNovB;
	}

	public int getPeriodDecA() {
		return periodDecA;
	}

	public void setPeriodDecA(int periodDecA) {
		this.periodDecA = periodDecA;
	}

	public int getPeriodDecB() {
		return periodDecB;
	}

	public void setPeriodDecB(int periodDecB) {
		this.periodDecB = periodDecB;
	}

	public long getOxygenRatingId() {
		return oxygenRatingId;
	}

	public void setOxygenRatingId(long oxygenRatingId) {
		this.oxygenRatingId = oxygenRatingId;
	}

	public long getCurrentRatingId() {
		return currentRatingId;
	}

	public void setCurrentRatingId(long currentRatingId) {
		this.currentRatingId = currentRatingId;
	}

	public long getRegionId() {
		return regionId;
	}

	public void setRegionId(long regionId) {
		this.regionId = regionId;
	}

	@Override
	public String toString() {
		return new StringBuilder().append("Site [").append(super.toString()).append("periodJanA=").append(periodJanA)
				.append(", periodJanB=").append(periodJanB).append(", periodFebA=").append(periodFebA)
				.append(", periodFebB=").append(periodFebB).append(", periodMarA=").append(periodMarA)
				.append(", periodMarB=").append(periodMarB).append(", periodAprA=").append(periodAprA)
				.append(", periodAprB=").append(periodAprB).append(", periodMayA=").append(periodMayA)
				.append(", periodMayB=").append(periodMayB).append(", periodJunA=").append(periodJunA)
				.append(", periodJunB=").append(periodJunB).append(", periodJulA=").append(periodJulA)
				.append(", periodJulB=").append(periodJulB).append(", periodAugA=").append(periodAugA)
				.append(", periodAugB=").append(periodAugB).append(", periodSepA=").append(periodSepA)
				.append(", periodSepB=").append(periodSepB).append(", periodOctA=").append(periodOctA)
				.append(", periodOctB=").append(periodOctB).append(", periodNovA=").append(periodNovA)
				.append(", periodNovB=").append(periodNovB).append(", periodDecA=").append(periodDecA)
				.append(", periodDecB=").append(periodDecB).append(", oxygenRatingId=").append(oxygenRatingId)
				.append(", currentRatingId=").append(currentRatingId).append(", regionId=").append(regionId).append("]")
				.toString();
	}

}
